@@ -59,17 +59,6 @@
 #'    per block in y.summary and y.potential, are representative of mean 
 #'    randomized durations per block across each shuffle unit (e.g., day 1 is 
 #'    representative of day 3, etc.).
-#'    
-#' Finally, in order to inform users of any warnings that arise in each
-#'    pairwise comparison, this function clears general warnings and saves any
-#'    sub-function related warning that occurs. Please note that running this 
-#'    function will clear the warning cache, so we suggest saving previous 
-#'    warnings to a log or file prior to running this code if users are 
-#'    interested in reviewing past warnings. Additionally, if users receive the
-#'    error: "Error in assign("last.warning", NULL, envir = baseenv()) :
-#'    cannot add binding of 'last.warning' to the base environment," we suggest
-#'    calling unlockBinding("last.warning", baseenv()) prior to using this 
-#'    function.
 #'
 #' @param x.summary List or single-data frame output from the summarizeContacts
 #'    function refering to the empirical data. Note that if x.summary is a list
@@ -223,7 +212,6 @@
 #'                                      blockUnit = "hours", blockLength = 1, 
 #'                                      distFunction = "dist2All_df") 
 #' 
-#' unlockBinding("last.warning", baseenv()) #this code ensures that we can always clear warnings
 #' 
 #' contactCompare_binom(x.summary = emp.summary, y.summary = rand.summary, 
 #'                      x.potential = emp.potential, y.potential = rand.potential,
@@ -395,8 +383,8 @@ contactCompare_binom<-function(x.summary, y.summary, x.potential, y.potential =
         
         expectedProb1 <- expectedProb[1] #unlike the chisq.test function, the binom.test function only accepts a vector of length one as the probability argument
 
-        assign("last.warning", NULL, envir = baseenv()) #clears the warnings
-        
+        warn1 <- NULL #clear warn1
+
         test<-tryCatch.W.E(stats::binom.test(x = observedVec, p = expectedProb1, ...))$value
         warn1<-tryCatch.W.E(stats::binom.test(x = observedVec, p = expectedProb1, ...))$warning$message
         
@@ -895,7 +883,7 @@ contactCompare_binom<-function(x.summary, y.summary, x.potential, y.potential =
           
           expectedProb1 <- expectedProb[1] #unline the chisq.test function, the binom.test function only accepts a vector of length one as the probability argument
           
-          assign("last.warning", NULL, envir = baseenv()) #clears the warnings
+          warn1 <- NULL #clear warn1
           
           test<-tryCatch.W.E(stats::binom.test(x = observedVec, p = expectedProb1, ...))$value
           warn1<-tryCatch.W.E(stats::binom.test(x = observedVec, p = expectedProb1, ...))$warning$message
@@ -997,7 +985,7 @@ contactCompare_binom<-function(x.summary, y.summary, x.potential, y.potential =
           
           expectedProb1 <- expectedProb[1] #unline the chisq.test function, the binom.test function only accepts a vector of length one as the probability argument
           
-          assign("last.warning", NULL, envir = baseenv()) #clears the warnings
+          warn1 <- NULL #clear warn1
           
           test<-tryCatch.W.E(stats::binom.test(x = observedVec, p = expectedProb1, ...))$value
           warn1<-tryCatch.W.E(stats::binom.test(x = observedVec, p = expectedProb1, ...))$warning$message
