@@ -6,17 +6,6 @@
 #'    networks created using our pipeline of contact:: functions.
 #'    Please understand that ape::mantel.test does not allow for missing
 #'    values in matrices, so all NAs will be treated as zeroes.
-#'    
-#' Note that in order to inform users of any warnings that arise in each
-#'    pairwise comparison, this function clears general warnings and saves any
-#'    sub-function related warning that occurs. Please note that running this 
-#'    function will clear the warning cache, so we suggest saving previous 
-#'    warnings to a log or file prior to running this code if users are 
-#'    interested in reviewing past warnings. Additionally, if users receive the
-#'    error: "Error in assign("last.warning", NULL, envir = baseenv()) :
-#'    cannot add binding of 'last.warning' to the base environment," we suggest
-#'    calling unlockBinding("last.warning", baseenv()) prior to using this 
-#'    function.
 #'
 #' @param x.summary List or single-data frame output from the summarizeContacts
 #'    function refering to the empirical data. Note that if x.summary is a list
@@ -99,7 +88,6 @@
 #' rand.summary <- summarizeContacts(calves.contact.rand, avg = TRUE,
 #'                                   importBlocks = TRUE) #NULL contact summary
 #' 
-#' unlockBinding("last.warning", baseenv()) #this code ensures that we can always clear warnings
 #'
 #' contactCompare_mantel(x.summary = emp.summary, y.summary = rand.summary,
 #'                     importBlocks = FALSE, numPermutations = 100,
@@ -284,7 +272,7 @@ contactCompare_mantel<-function(x.summary, y.summary, numPermutations = 1000, al
       emp.matrix[which(is.na(emp.matrix) == TRUE)]<-0 
       rand.matrix[which(is.na(rand.matrix) == TRUE)]<-0
       
-      assign("last.warning", NULL, envir = baseenv()) #clears any warnings
+      warn1 <- NULL #clear warnings
       
       test.tryCatch<-tryCatch.W.E(ape::mantel.test(emp.matrix, rand.matrix, nperm = numPermutations, alternative = alternative.hyp)) #perform the mantel test
       output.test<-test.tryCatch$value #pull the value
